@@ -1,11 +1,11 @@
 /*
-  Copyright 1999-2016 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2018 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
   
-    http://www.imagemagick.org/script/license.php
+    https://www.imagemagick.org/script/license.php
   
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -15,8 +15,8 @@
 
   MagickCore module methods.
 */
-#ifndef _MAGICKCORE_MODULE_H
-#define _MAGICKCORE_MODULE_H
+#ifndef MAGICKCORE_MODULE_H
+#define MAGICKCORE_MODULE_H
 
 #include <time.h>
 #include "magick/version.h"
@@ -85,9 +85,7 @@ extern MagickExport ModuleInfo
 
 extern MagickExport void
   DestroyModuleList(void),
-  ModuleComponentTerminus(void),
-  RegisterStaticModules(void),
-  UnregisterStaticModules(void);
+  ModuleComponentTerminus(void);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
