@@ -27,12 +27,12 @@ extern "C" {
 */
 #define MagickPackageName "ImageMagick"
 #define MagickCopyright  "© 1999-2018 ImageMagick Studio LLC"
-#define MagickLibVersion  0x699
-#define MagickLibVersionText  "6.9.9"
-#define MagickLibVersionNumber  5,0,0
-#define MagickLibAddendum  "-38"
-#define MagickLibInterface  5
-#define MagickLibMinInterface  5
+#define MagickLibVersion  0x69A
+#define MagickLibVersionText  "6.9.10"
+#define MagickLibVersionNumber  6,0,0
+#define MagickLibAddendum  "-10"
+#define MagickLibInterface  6
+#define MagickLibMinInterface  6
 #if defined(_WINDOWS)
 #  if defined(_WIN64)
 #    define MagickPlatform "x64"
@@ -40,18 +40,18 @@ extern "C" {
 #    define MagickPlatform "x86"
 #  endif
 #else
-#define MagickPlatform  "aarch64"
+#define MagickPlatform  "powerpc"
 #endif
-#define MagickppLibVersionText  "6.9.9"
+#define MagickppLibVersionText  "6.9.10"
 #define MagickppLibVersionNumber  8:0:0
-#define MagickppLibAddendum  "-38"
+#define MagickppLibAddendum  "-10"
 #define MagickppLibInterface  8
 #define MagickppLibMinInterface  8
-#define MagickReleaseDate  "2018-03-27"
+#define MagickReleaseDate  "2018-10-15"
 #define MagickHomeURL  "file:///usr/local/share/doc/ImageMagick/index.html"
 #define MagickAuthoritativeLicense  \
-  "http://www.imagemagick.org/script/license.php"
-#define MagickAuthoritativeURL  "http://www.imagemagick.org"
+  "https://www.imagemagick.org/script/license.php"
+#define MagickAuthoritativeURL  "https://www.imagemagick.org"
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
 #define MagickQuantumDepth  "Q8"
 #define MagickQuantumRange  "255"
