@@ -1,11 +1,11 @@
 /*
-  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2018 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
 
-    http://www.imagemagick.org/script/license.php
+    https://www.imagemagick.org/script/license.php
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -16,8 +16,8 @@
   MagickWand image Methods.
 */
 
-#ifndef _MAGICKWAND_MAGICK_IMAGE_H
-#define _MAGICKWAND_MAGICK_IMAGE_H
+#ifndef MAGICKWAND_MAGICK_IMAGE_H
+#define MAGICKWAND_MAGICK_IMAGE_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
@@ -94,6 +94,7 @@ extern WandExport MagickBooleanType
   MagickAutoGammaImageChannel(MagickWand *,const ChannelType),
   MagickAutoLevelImage(MagickWand *),
   MagickAutoLevelImageChannel(MagickWand *,const ChannelType),
+  MagickAutoOrientImage(MagickWand *),
   MagickBlackThresholdImage(MagickWand *,const PixelWand *),
   MagickBlueShiftImage(MagickWand *,const double),
   MagickBlurImage(MagickWand *,const double,const double),
@@ -118,9 +119,12 @@ extern WandExport MagickBooleanType
   MagickCommentImage(MagickWand *,const char *),
   MagickCompositeImage(MagickWand *,const MagickWand *,const CompositeOperator,
     const ssize_t,const ssize_t),
+  MagickCompositeImageChannel(MagickWand *,const ChannelType,const MagickWand *,
+    const CompositeOperator,const ssize_t,const ssize_t),
+  MagickCompositeImageGravity(MagickWand *,const MagickWand *,const CompositeOperator,
+    const GravityType),
   MagickCompositeLayers(MagickWand *,const MagickWand *,const CompositeOperator,
     const ssize_t,const ssize_t),
-  MagickCompositeImageChannel(MagickWand *,const ChannelType,const MagickWand *,    const CompositeOperator,const ssize_t,const ssize_t),
   MagickConstituteImage(MagickWand *,const size_t,const size_t,const char *,
     const StorageType,const void *),
   MagickContrastImage(MagickWand *,const MagickBooleanType),
@@ -213,6 +217,7 @@ extern WandExport MagickBooleanType
   MagickLinearStretchImage(MagickWand *,const double,const double),
   MagickLiquidRescaleImage(MagickWand *,const size_t,const size_t,const double,
     const double),
+  MagickLocalContrastImage(MagickWand *,const double,const double),
   MagickMagnifyImage(MagickWand *),
   MagickMedianFilterImage(MagickWand *,const double),
   MagickMinifyImage(MagickWand *),
@@ -240,6 +245,7 @@ extern WandExport MagickBooleanType
   MagickOrderedPosterizeImage(MagickWand *,const char *),
   MagickOrderedPosterizeImageChannel(MagickWand *,const ChannelType,
     const char *),
+  MagickOptimizeImageTransparency(MagickWand *),
   MagickTransparentPaintImage(MagickWand *,const PixelWand *,
     const double,const double,const MagickBooleanType invert),
   MagickPingImage(MagickWand *,const char *),
@@ -252,8 +258,6 @@ extern WandExport MagickBooleanType
     const size_t,const MagickBooleanType,const MagickBooleanType),
   MagickQuantizeImages(MagickWand *,const size_t,const ColorspaceType,
     const size_t,const MagickBooleanType,const MagickBooleanType),
-  MagickRadialBlurImage(MagickWand *,const double),
-  MagickRadialBlurImageChannel(MagickWand *,const ChannelType,const double),
   MagickRaiseImage(MagickWand *,const size_t,const size_t,const ssize_t,
     const ssize_t,const MagickBooleanType),
   MagickRandomThresholdImage(MagickWand *,const double,const double),
@@ -272,6 +276,9 @@ extern WandExport MagickBooleanType
     const double),
   MagickRollImage(MagickWand *,const ssize_t,const ssize_t),
   MagickRotateImage(MagickWand *,const PixelWand *,const double),
+  MagickRotationalBlurImage(MagickWand *,const double),
+  MagickRotationalBlurImageChannel(MagickWand *,const ChannelType,
+    const double),
   MagickSampleImage(MagickWand *,const size_t,const size_t),
   MagickScaleImage(MagickWand *,const size_t,const size_t),
   MagickSegmentImage(MagickWand *,const ColorspaceType,const MagickBooleanType,
@@ -339,15 +346,16 @@ extern WandExport MagickBooleanType
     const MagickBooleanType,const double,const double),
   MagickSketchImage(MagickWand *,const double,const double,const double),
   MagickSolarizeImage(MagickWand *,const double),
+  MagickSolarizeImageChannel(MagickWand *,const ChannelType,const double),
   MagickSparseColorImage(MagickWand *,const ChannelType,const SparseColorMethod,
     const size_t,const double *),
   MagickSpliceImage(MagickWand *,const size_t,const size_t,const ssize_t,
     const ssize_t),
   MagickSpreadImage(MagickWand *,const double),
-  MagickStatisticImage(MagickWand *,const ChannelType,const StatisticType,
-    const size_t,const size_t),
-  MagickStatisticImageChannel(MagickWand *,const StatisticType,const size_t,
+  MagickStatisticImage(MagickWand *,const StatisticType,const size_t,
     const size_t),
+  MagickStatisticImageChannel(MagickWand *,const ChannelType,
+    const StatisticType,const size_t,const size_t),
   MagickStripImage(MagickWand *),
   MagickSwirlImage(MagickWand *,const double),
   MagickTintImage(MagickWand *,const PixelWand *,const PixelWand *),
@@ -372,7 +380,7 @@ extern WandExport MagickBooleanType
   MagickWriteImages(MagickWand *,const char *,const MagickBooleanType),
   MagickWriteImagesFile(MagickWand *,FILE *);
 
-WandExport MagickProgressMonitor
+extern WandExport MagickProgressMonitor
   MagickSetImageProgressMonitor(MagickWand *,const MagickProgressMonitor,
     void *);
 
